@@ -13,6 +13,9 @@ random_ref <- function(pkgname = NULL, pkgVersion = NULL, random_n = 2){
   }
   msg <- "If you use the ggtree package suite in published research, please cite the appropriate paper(s):\n\n" 
   refs <- c(
+    ggtreeBook = paste("Guangchuang Yu. (2022).",
+                        "Data Integration, Manipulation and Visualization of Phylogenetic Trees (1st edition).",
+                        "Chapman and Hall/CRC.\n"),
     ggtreeCPB = paste0(
       "Guangchuang Yu. ",
       "Using ggtree to visualize data on tree-like structures. ",
